#include "StdAfx.h"
#include "ScrollBarEx.h"

CScrollBarEx::CScrollBarEx(void)
{
	m_pScrollBar = NULL;

}

CScrollBarEx::~CScrollBarEx(void)
{
}

LPCTSTR CScrollBarEx::GetWindowClassName() const
{
	return _T("SCROLLBAREX");
}

void CScrollBarEx::Notify(TNotifyUI& msg)
{	
	//only message DUI_MSGTYPE_SCROLL need to be sent to parent window.
	if (msg.sType == DUI_MSGTYPE_SCROLL)
	{ 
		//::PostMessage(::GetParent(m_hWnd),WM_VSCROLL,MAKEWPARAM(SB_THUMBTRACK,m_pScrollBar->GetScrollPos()),(LPARAM)m_hWnd);
		::PostMessage(::GetParent(m_hWnd),WM_VSCROLL_VIEW,m_pScrollBar->GetScrollPos(),(LPARAM)this);
	}
}

void CScrollBarEx::OnFinalMessage(HWND hWnd)
{

}

void CScrollBarEx::InitWindow()
{
	m_pScrollBar = (CScrollBarUI *)m_PaintManager.FindControl(_T("cvscrollbar"));
	_ASSERT(m_pScrollBar);
}

UILIB_RESOURCETYPE CScrollBarEx::GetResourceType() const
{
	return UILIB_FILE;
}


CDuiString CScrollBarEx::GetSkinFile()
{
	return _T("chatscrollex.xml");
}

CDuiString CScrollBarEx::GetSkinFolder()
{
	return _T("skin\\nTalkRes");
}

BOOL CScrollBarEx::Create(DWORD dwStyle, const RECT& rect, CWnd* pParentWnd, UINT nID)
{
	HWND hwnd = __super::Create(pParentWnd->m_hWnd,_T("SCROLLBAREX"),dwStyle|WS_VISIBLE,NULL,rect,NULL);
	return hwnd != NULL;
}

// Attributes
int CScrollBarEx::GetScrollPos() const
{
	if (m_pScrollBar)
	{
		return m_pScrollBar->GetScrollPos();
	}
	return 0;
}

int CScrollBarEx::SetScrollPos(int nPos, BOOL bRedraw)
{
	if (m_pScrollBar)
	{
		m_pScrollBar->SetScrollPos(nPos);
		if (bRedraw)
		{
			InvalidateRect(m_hWnd,NULL,TRUE);
		}
	}
	return 0;
}

void CScrollBarEx::GetScrollRange(LPINT lpMinPos, LPINT lpMaxPos) const
{
	if (m_pScrollBar)
	{
		*lpMinPos = 0;
		*lpMaxPos = m_pScrollBar->GetScrollRange();
	}
	return;
}

void CScrollBarEx::SetScrollRange(int nMinPos, int nMaxPos, BOOL bRedraw)
{
	if (m_pScrollBar)
	{
		m_pScrollBar->SetScrollRange(nMaxPos);
		if (bRedraw)
		{
			InvalidateRect(m_hWnd,NULL,TRUE);
		}
	}
	return;
}

void CScrollBarEx::ShowScrollBar(BOOL bShow)
{
	if (::IsWindow(m_hWnd))
	{
		ShowWindow(bShow?true:false, false);
	}

	if (m_pScrollBar)
	{
		m_pScrollBar->SetVisible(bShow?true:false);
	}
	return;
}


BOOL CScrollBarEx::EnableScrollBar(UINT nArrowFlags)
{
	EnableWindow(m_hWnd,nArrowFlags);
	return true;
}


BOOL CScrollBarEx::SetScrollInfo(LPSCROLLINFO lpScrollInfo, BOOL bRedraw)
{
	
	if (lpScrollInfo->fMask & SIF_RANGE)
	{
		m_pScrollBar->SetScrollRange(lpScrollInfo->nMax - lpScrollInfo->nPage);
	}
	
	if (lpScrollInfo->fMask & SIF_POS)
	{
		m_pScrollBar->SetScrollPos(lpScrollInfo->nPos);
	}
// 	
// 	if (lpScrollInfo->fMask & SIF_PAGE)
// 	{
// 		//m_pScrollBar->SetLineSize(lpScrollInfo->nPage/10);
// 	}
	
	return true;
}

BOOL CScrollBarEx::GetScrollInfo(LPSCROLLINFO lpScrollInfo, UINT nMask)
{
	if (nMask & SIF_RANGE)
	{
		lpScrollInfo->nMin = 0;
		lpScrollInfo->nMax = m_pScrollBar->GetScrollRange() + m_pScrollBar->GetHeight();
	}

	if (nMask & SIF_POS)
	{
		lpScrollInfo->nPos = m_pScrollBar->GetScrollPos();
	}

	if (nMask & SIF_PAGE)
	{
		lpScrollInfo->nPage = m_pScrollBar->GetHeight();
	}
	return true;
}

int CScrollBarEx::GetScrollLimit()
{
	return m_pScrollBar->GetScrollRange();
}


int CScrollBarEx::MoveWindow(RECT *rc)
{
	if (::IsWindow(m_hWnd))
	{
		SetWindowPos(m_hWnd,0,rc->left,rc->top,rc->right - rc->left,rc->bottom - rc->top,0);
	}

	return 0;
}

BOOL CScrollBarEx::IsWindowEnabled()
{
	return ::IsWindowEnabled(m_hWnd);
}

BOOL CScrollBarEx::IsWindowVisible()
{
	return ::IsWindowVisible(m_hWnd);
}